==> Statemate4.6.1.4Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Data Import Reference/wwhdata/js/search/pairs/pair32.js <==
function FileData_Pairs(x)
{
x.t("creation","functions");
x.t("description","stm_context");
x.t("cn_name","cn_type");
x.t("arguments","argument");
x.t("creates","connector");
x.t("double","connector");
x.t("coordinate","y_pos");
x.t("type","argument");
x.t("type","status_code");
x.t("type","x_pos");
x.t("enumeration_stm_","connector_type");
x.t("chart_name","cn_name");
x.t("chart_name","input");
x.t("name","cn_type");
x.t("name","input/");
x.t("argument","description");
x.t("argument","type");
x.t("argument","name");
x.t("y_pos","input");
x.t("y_pos","return");
x.t("string","chart");
x.t("input","double");
x.t("input","enumeration_stm_");
x.t("input","string");
x.t("input","pointer");
x.t("functions","stmcreateconnector");
x.t("bystminitimport","chart_name");
x.t("syntax","stmcreateconnector");
x.t("chart","name");
x.t("chart","syntax");
x.t("returned","bystminitimport");
x.t("status_code","arguments");
x.t("connector","coordinate");
x.t("connector","type");
x.t("connector","chart");
x.t("return","type");
x.t("x_pos","y_pos");
x.t("x_pos","input");
x.t("stm","context");
x.t("connector_type","connector");
x.t("stm_context","chart_name");
x.t("stm_context","input");
x.t("output","argument");
x.t("context","descriptor");
x.t("stmcreateconnector","creation");
x.t("stmcreateconnector","creates");
x.t("stmcreateconnector","stm_context");
x.t("stmcreateconnector","stmcreateconnector");
x.t("pointer","stm");
x.t("cn_type","input");
x.t("cn_type","x_pos");
x.t("input/","output");
x.t("descriptor","returned");
}

==> Statemate4.6.1.10Documentation.tar.gz: STM_HELP/help_doc/MultiVolume/Output/Data Import Reference/wwhdata/js/search/pairs/pair32.js <==
function FileData_Pairs(x)
{
x.t("creation","functions");
x.t("description","stm_context");
x.t("cn_name","output");
x.t("cn_name","cn_type");
x.t("arguments","argument");
x.t("creates","connector");
x.t("double","connector");
x.t("coordinate","y_pos");
x.t("type","argument");
x.t("type","status_code");
x.t("type","x_pos");
x.t("enumeration_stm_","connector_type");
x.t("chart_name","cn_name");
x.t("chart_name","input");
x.t("name","cn_name");
x.t("name","actually");
x.t("name","created");
x.t("name","input/");
x.t("argument","description");
x.t("argument","type");
x.t("argument","name");
x.t("y_pos","input");
x.t("y_pos","return");
x.t("string","chart");
x.t("string","connector");
x.t("string","cn_type");
x.t("input","double");
x.t("input","enumeration_stm_");
x.t("input","string");
x.t("input","pointer");
x.t("functions","stmcreateconnector");
x.t("bystminitimport","chart_name");
x.t("syntax","stmcreateconnector");
x.t("chart","name");
x.t("chart","syntax");
x.t("returned","bystminitimport");
x.t("returned","malloced");
x.t("status_code","arguments");
x.t("connector","coordinate");
x.t("connector","type");
x.t("connector","name");
x.t("connector","chart");
x.t("connector","returned");
x.t("return","type");
x.t("x_pos","y_pos");
x.t("x_pos","input");
x.t("stm","context");
x.t("connector_type","connector");
x.t("actually","connector");
x.t("stm_context","chart_name");
x.t("stm_context","input");
x.t("output","argument");
x.t("output","pointer");
x.t("context","descriptor");
x.t("malloced","string");
x.t("stmcreateconnector","creation");
x.t("stmcreateconnector","creates");
x.t("stmcreateconnector","stm_context");
x.t("stmcreateconnector","stmcreateconnector");
x.t("created","name");
x.t("pointer","string");
x.t("pointer","stm");
x.t("cn_type","input");
x.t("cn_type","x_pos");
x.t("input/","output");
x.t("descriptor","returned");
}
